@@ -138,6 +138,9 @@ public class XmlVmBaseReader {
                 case "os":
                 object.os(XmlOperatingSystemReader.readOne(reader));
                 break;
+                case "quota":
+                object.quota(XmlQuotaReader.readOne(reader));
+                break;
                 case "rng_device":
                 object.rngDevice(XmlRngDeviceReader.readOne(reader));
                 break;
